Welcome to Fabric!
==================

.. include:: ../../README.rst

----

This website covers project information for Fabric such as the changelog,
contribution guidelines, development roadmap, news/blog, and so forth.
Detailed usage and API documentation can be found at our code documentation
site, `docs.fabfile.org <http://docs.fabfile.org>`_.

Please see the navigation sidebar to the left to begin.

.. toctree::
    :hidden:

    changelog
    FAQs <faq>
    installing
    troubleshooting
    development
    Roadmap <roadmap>
    contact
